==> deepin-log-viewer_5.8.32.orig.tar.xz: deepin-log-viewer-5.8.32/translations/deepin-log-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Esborra el registre</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Segur que voleu esborrar el registre?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dies</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 setmana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporta</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arrencada</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>S&apos;exporta...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportació correcta</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ha fallat l&apos;exportació.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporta el fitxer</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Període:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Llista d&apos;aplicacions:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipus d&apos;esdeveniment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acció:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Historial d&apos;aturada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Historial d&apos;entrada</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El fitxer de registre és buit.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registres</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>El Visor de registres és una eina útil per veure els registres del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de cerca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Procés</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipus d&apos;esdeveniment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Procés:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dia i hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informació:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registre del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registre del nucli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registre del dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registre de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registre del Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registre d&apos;aplicacions</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Esdeveniment d&apos;arrencada-aturada</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registre de dnf</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.0.7.orig.tar.xz: deepin-log-viewer-6.0.7/translations/deepin-log-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Esborra el registre</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Segur que voleu esborrar el registre?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dies</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 setmana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporta</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arrencada</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>S&apos;exporta...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportació correcta</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ha fallat l&apos;exportació.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporta el fitxer</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Període:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Llista d&apos;aplicacions:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipus d&apos;esdeveniment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acció:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Historial d&apos;aturada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Historial d&apos;entrada</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El fitxer de registre és buit.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registres</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>El Visor de registres és una eina útil per veure els registres del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de cerca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Procés</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipus d&apos;esdeveniment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Procés:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dia i hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informació:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registre del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registre del nucli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registre del dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registre de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registre del Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registre d&apos;aplicacions</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Esdeveniment d&apos;arrencada-aturada</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registre de dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval de refresc</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 segons</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sense refresc</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exporta-ho tot</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Registres del sistema</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Refresca-ho ara</translation>
    </message>
</context>
</TS>
